# FICTURE

FICTURE: Scalable segmentation-free analysis of sub-micron resolution spatial transcriptomics

Install 
```
pip install ficture
```

Documentation [https://seqscope.github.io/ficture/](https://seqscope.github.io/ficture/)

[Preprint](https://biorxiv.org/cgi/content/short/2023.11.04.565621v2) (Real data results in the preprint are [available on Zenodo](https://zenodo.org/records/10070621))

For a brief introduction, see [slides used for AGBT talk](http://tinyurl.com/47pbktzp)
